@@ -41,8 +41,8 @@ mdes.bcrd3f2 <- function(power = .80, alpha = .05, two.tailed = TRUE,
                    df = df,
                    sse = sse,
                    mdes = mdes)
-  print(round(mdes, 3))
   class(mdes.out) <- c("mdes", "bcrd3f2")
+  .summary.mdes(mdes.out)
   return(invisible(mdes.out))
 }
 
@@ -95,9 +95,8 @@ power.bcrd3f2 <- function(es = .25, alpha = .05, two.tailed = TRUE,
                      df = df,
                      sse = sse,
                      power = power)
-  names(power) <- "power"
-  print(round(power, 3))
   class(power.out) <- c("power", "bcrd3f2")
+  .summary.power(power.out)
   return(invisible(power.out))
 }
 # example
@@ -199,8 +198,8 @@ cosa.bcrd3f2 <- function(cn1 = 0, cn2 = 0, cn3 = 0, cost = NULL,
                                 rho2 = rho2, r21 = r21, r22 = r22,
                                 g2 = g2, p0 = p0, p = p, n0 = n0, n1 = n1, n2 = n2, n3 = n3),
                    cosa = cosa)
-  print(round(cosa, 3))
   class(cosa.out) <- c("cosa", "bcrd3f2")
+  .summary.cosa(cosa.out)
   return(invisible(cosa.out))
 }
 # examples
