@@ -45,8 +45,8 @@ mdes.bcrd4r3 <- function(power = .80, alpha = .05, two.tailed = TRUE,
                    df = df,
                    sse = sse,
                    mdes = mdes)
-  print(round(mdes, 3))
   class(mdes.out) <- c("mdes", "bcrd4r3")
+  .summary.mdes(mdes.out)
   return(invisible(mdes.out))
 }
 
@@ -102,9 +102,8 @@ power.bcrd4r3 <- function(es = .25, alpha = .05, two.tailed = TRUE,
                      df = df,
                      sse = sse,
                      power = power)
-  names(power) <- "power"
-  print(round(power, 3))
   class(power.out) <- c("power", "bcrd4r3")
+  .summary.power(power.out)
   return(invisible(power.out))
 }
 # example
@@ -227,8 +226,8 @@ cosa.bcrd4r3 <- function(cn1 = 0, cn2 = 0, cn3 = 0, cn4 = 0, cost = NULL,
                                 g4 = g4, p0 = p0, p = p, n0 = n0,
                                 n1 = n1, n2 = n2, n3 = n3, n4 = n4),
                    cosa = cosa)
-  print(round(cosa, 3))
   class(cosa.out) <- c("cosa", "bcrd4r3")
+  .summary.cosa(cosa.out)
   return(invisible(cosa.out))
 }
 # examples
